[![PyPI version](https://badge.fury.io/py/alpha-automl.svg)](https://badge.fury.io/py/alpha-automl)

Alpha-AutoML
===========

Alpha-AutoML is an AutoML system that automatically searches for models and derives end-to-end pipelines that read, 
pre-process the data, and train the model. Alpha-AutoML leverages recent advances in deep reinforcement learning and is 
able to adapt to different application domains and problems through incremental learning.

Alpha-AutoML provides data scientists and data engineers the flexibility to address complex problems by leveraging the 
Python ecosystem, including open-source libraries and tools, support for collaboration, and infrastructure that enables 
transparency and reproducibility. 

This repository is part of New York University's implementation of the 
[Data Driven Discovery project (D3M)](https://datadrivendiscovery.org/).


## Installation

This package works with Python 3.6+ in Linux, Mac and Windows.

You can install the latest stable version of this library from [PyPI](https://pypi.org/project/alpha-automl/):

```
$ pip install alpha-automl
```

To install the latest development version:

```
$ pip install git+https://github.com/VIDA-NYU/alpha-automl@devel
```
